## $Id: session_results_presentation.py 14508 2017-02-05 20:12:54Z henrik $
##
## Copyright (C) 2013 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##

import grok
from zope.component import getUtility
from waeup.kofa.interfaces import IKofaUtils
from waeup.kofa.students.reports.session_results_presentation import (
    SessionResultsPresentation, SessionResultsPresentationGenerator)

class CustomSessionResultsPresentation(SessionResultsPresentation):

    note = ""

    pdfcreator = ''

    @property
    def introduction (self):
        site = grok.getSite()
        degrees_dict = getUtility(IKofaUtils).DEGREES_DICT
        if self.certcode == 'all':
            text = """I present to Senate, on behalf of the Faculty Board,
the results of courses taught and examinations held this academic session.
The following candidate(s) have/have not satisfied the degree requirements
of the Faculty and have/have not qualified for the award of an academic
degree as stated below:
"""
        else:
            certificate = site['faculties'][self.faccode][
                self.depcode].certificates[self.certcode]
            degree = degrees_dict.get(certificate.degree, '[undefined]')
            text = """I present to Senate, on behalf of the Faculty Board,
the results of courses taught and examinations held this academic session.
The following candidate(s) have/have not satisfied the degree requirements
of the Faculty and have/have not qualified for the award of a %s as stated
below:
""" % degree
        return text

#    note = """
#<br /><br /><br /><br />
#<font size='10'>
#<strong>Note:</strong> This copy is subject to correction for typographical errors and ratification by the departmental board.
#</font>
#"""

    signatures = ['Head of Department', 'External Examiner', 'Dean of Faculty']

class CustomSessionResultsPresentationGenerator(
    SessionResultsPresentationGenerator):

    def generate(self, site, faccode=None, depcode=None, certcode=None,
                 session=None, level=None, author=None):
        result = CustomSessionResultsPresentation(faccode=faccode,
            depcode=depcode, certcode=certcode, session=session,
            level=level, author=author)
        return result
